/*
* Copyright (c) 2023 - 2024 MINRES Technologies GmbH
*
* SPDX-License-Identifier: Apache-2.0
*
* Generated at 2024-04-22 11:11:53 UTC 
* by peakrdl_mnrs version 1.2.2
*/

#ifndef _BSP_I2SMODULE_H
#define _BSP_I2SMODULE_H

#include <stdint.h>

typedef struct __attribute((__packed__)) {
    volatile uint32_t LEFT_CH;
    volatile uint32_t RIGHT_CH;
    volatile uint32_t CONTROL;
    volatile uint32_t STATUS;
    volatile uint32_t I2S_CLOCK_CTRL;
    volatile uint32_t PDM_CLOCK_CTRL;
    volatile uint32_t IE;
    volatile uint32_t IP;
}i2smodule_t;

static inline uint32_t get_i2smodule_data_left(volatile i2smodule_t *reg){
    return (reg->LEFT_CH >> 0) & 0xffffffff;
}

static inline void set_i2smodule_data_left(volatile i2smodule_t *reg, uint32_t value){
    reg->LEFT_CH = (reg->LEFT_CH & ~(0xffffffffU << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_data_right(volatile i2smodule_t *reg){
    return (reg->RIGHT_CH >> 0) & 0xffffffff;
}

static inline void set_i2smodule_data_right(volatile i2smodule_t *reg, uint32_t value){
    reg->RIGHT_CH = (reg->RIGHT_CH & ~(0xffffffffU << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_mode(volatile i2smodule_t *reg){
    return (reg->CONTROL >> 0) & 0x3;
}

static inline void set_i2smodule_mode(volatile i2smodule_t *reg, uint8_t value){
    reg->CONTROL = (reg->CONTROL & ~(0x3U << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_disable_left(volatile i2smodule_t *reg){
    return (reg->CONTROL >> 2) & 0x1;
}

static inline void set_i2smodule_disable_left(volatile i2smodule_t *reg, uint8_t value){
    reg->CONTROL = (reg->CONTROL & ~(0x1U << 2)) | (value << 2);
}

static inline uint32_t get_i2smodule_disable_right(volatile i2smodule_t *reg){
    return (reg->CONTROL >> 3) & 0x1;
}

static inline void set_i2smodule_disable_right(volatile i2smodule_t *reg, uint8_t value){
    reg->CONTROL = (reg->CONTROL & ~(0x1U << 3)) | (value << 3);
}

static inline uint32_t get_i2smodule_active_clock(volatile i2smodule_t *reg){
    return (reg->CONTROL >> 4) & 0x1;
}

static inline void set_i2smodule_active_clock(volatile i2smodule_t *reg, uint8_t value){
    reg->CONTROL = (reg->CONTROL & ~(0x1U << 4)) | (value << 4);
}

static inline uint32_t get_i2smodule_pdm_scale(volatile i2smodule_t *reg){
    return (reg->CONTROL >> 5) & 0x7;
}

static inline void set_i2smodule_pdm_scale(volatile i2smodule_t *reg, uint8_t value){
    reg->CONTROL = (reg->CONTROL & ~(0x7U << 5)) | (value << 5);
}

static inline uint32_t get_i2smodule_enabled(volatile i2smodule_t *reg){
    return (reg->STATUS >> 0) & 0x1;
}

static inline uint32_t get_i2smodule_active(volatile i2smodule_t *reg){
    return (reg->STATUS >> 1) & 0x1;
}

static inline uint32_t get_i2smodule_left_avail(volatile i2smodule_t *reg){
    return (reg->STATUS >> 2) & 0x1;
}

static inline uint32_t get_i2smodule_right_avail(volatile i2smodule_t *reg){
    return (reg->STATUS >> 3) & 0x1;
}

static inline uint32_t get_i2smodule_both_avail(volatile i2smodule_t *reg){
    return (reg->STATUS >> 4) & 0x1;
}

static inline uint32_t get_i2smodule_divider(volatile i2smodule_t *reg){
    return (reg->I2S_CLOCK_CTRL >> 0) & 0xfffff;
}

static inline void set_i2smodule_divider(volatile i2smodule_t *reg, uint32_t value){
    reg->I2S_CLOCK_CTRL = (reg->I2S_CLOCK_CTRL & ~(0xfffffU << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_divider(volatile i2smodule_t *reg){
    return (reg->PDM_CLOCK_CTRL >> 0) & 0x3ff;
}

static inline void set_i2smodule_divider(volatile i2smodule_t *reg, uint16_t value){
    reg->PDM_CLOCK_CTRL = (reg->PDM_CLOCK_CTRL & ~(0x3ffU << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_en_left_sample_avail(volatile i2smodule_t *reg){
    return (reg->IE >> 0) & 0x1;
}

static inline void set_i2smodule_en_left_sample_avail(volatile i2smodule_t *reg, uint8_t value){
    reg->IE = (reg->IE & ~(0x1U << 0)) | (value << 0);
}

static inline uint32_t get_i2smodule_en_right_sample_avail(volatile i2smodule_t *reg){
    return (reg->IE >> 1) & 0x1;
}

static inline void set_i2smodule_en_right_sample_avail(volatile i2smodule_t *reg, uint8_t value){
    reg->IE = (reg->IE & ~(0x1U << 1)) | (value << 1);
}

static inline uint32_t get_i2smodule_left_sample_avail(volatile i2smodule_t *reg){
    return (reg->IP >> 0) & 0x1;
}

static inline uint32_t get_i2smodule_right_sample_avail(volatile i2smodule_t *reg){
    return (reg->IP >> 1) & 0x1;
}

#endif /* _BSP_I2SMODULE_H */